@@ -1,4 +1,3 @@
-/* $Id: mcast.c,v 1.15.2.4 2005/01/12 02:25:47 horms Exp $ */
 /*
  * mcast.c: implements hearbeat API for UDP multicast communication
  *
@@ -23,7 +22,7 @@
  *
  */
 
-#include <portability.h>
+#include <lha_internal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -77,31 +76,6 @@ static int		mcast_mtype(char** buffer);
 static int		mcast_isping(void);
 
 
-/*
- * mcastclose is called as part of unloading the mcast HBcomm plugin.
- * If there was any global data allocated, or file descriptors opened, etc.
- * which is associated with the plugin, and not a single interface
- * in particular, here's our chance to clean it up.
- */
-
-static void
-mcastclosepi(PILPlugin*pi)
-{
-}
-
-
-/*
- * mcastcloseintf called as part of shutting down the mcast HBcomm interface.
- * If there was any global data allocated, or file descriptors opened, etc.
- * which is associated with the mcast implementation, here's our chance
- * to clean it up.
- */
-static PIL_rc
-mcastcloseintf(PILInterface* pi, void* pd)
-{
-	return PIL_OK;
-}
-
 static struct hb_media_fns mcastOps ={
 	NULL,		/* Create single object function */
 	mcast_parse,	/* whole-line parse function */
@@ -114,7 +88,7 @@ static struct hb_media_fns mcastOps ={
 	mcast_isping,
 };
 
-PIL_PLUGIN_BOILERPLATE("1.0", Debug, mcastclosepi);
+PIL_PLUGIN_BOILERPLATE2("1.0", Debug)
 static const PILPluginImports*  PluginImports;
 static PILPlugin*               OurPlugin;
 static PILInterface*		OurInterface;
@@ -145,7 +119,7 @@ PIL_PLUGIN_INIT(PILPlugin*us, const PILPluginImports* imports)
  	return imports->register_interface(us, PIL_PLUGINTYPE_S
 	,	PIL_PLUGIN_S
 	,	&mcastOps
-	,	mcastcloseintf		/*close */
+	,	NULL		/*close */
 	,	&OurInterface
 	,	(void*)&OurImports
 	,	interfprivate); 
@@ -181,18 +155,19 @@ mcast_mtype(char** buffer)
 		return 0;
 	}
 
-	return STRLEN(*buffer);
+	return STRLEN_CONST(PIL_PLUGIN_S);
 }
 
 static int
 mcast_descr(char **buffer)
 { 
-	*buffer = STRDUP("UDP/IP multicast");
+	const char cret[] = "UDP/IP multicast";
+	*buffer = STRDUP(cret);
 	if (!*buffer) {
 		return 0;
 	}
 
-	return STRLEN(*buffer);
+	return STRLEN_CONST(cret);
 }
 
 static int
@@ -216,14 +191,14 @@ mcast_isping(void)
 static int
 mcast_parse(const char *line)
 {
-	const char *	bp = line;
-	char		dev[MAXLINE];
-	char		mcast[MAXLINE];
-	char		token[MAXLINE];
-	u_short		port;
-	u_char		ttl;
-	u_char		loop;
-	int		toklen;
+	const char *		bp = line;
+	char			dev[MAXLINE];
+	char			mcast[MAXLINE];
+	char			token[MAXLINE];
+	u_short			port = 0;	/* Bogus */
+	u_char			ttl = 10;	/* Bogus */
+	u_char			loop = 10;	/* Bogus */
+	int			toklen;
 	struct hb_media *	mp;
 
 	/* Skip over white space, then grab the device */
@@ -235,7 +210,7 @@ mcast_parse(const char *line)
 
 	if (*dev != EOS)  {
 		if (!is_valid_dev(dev)) {
-			PILCallLog(LOG, PIL_CRIT, "mcast bad device [%s]", dev);
+			PILCallLog(LOG, PIL_CRIT, "mcast device [%s] is invalid or not set up properly", dev);
 			return HA_FAIL;
 		}
 		/* Skip over white space, then grab the multicast group */
@@ -263,10 +238,11 @@ mcast_parse(const char *line)
 		token[toklen] = EOS;
 
 		if (*token == EOS)  {
-			PILCallLog(LOG, PIL_CRIT, "mcast [%s] missing port", dev);
+			PILCallLog(LOG, PIL_CRIT, "mcast [%s] missing port"
+			,	dev);
 			return(HA_FAIL);
 		}
-		if (get_port(token, &port) == -1) {
+		if (get_port(token, &port) < 0 || port <= 0) {
 			PILCallLog(LOG, PIL_CRIT, " mcast [%s] bad port [%d]", dev, port);
 			return HA_FAIL;
 		}
@@ -282,7 +258,7 @@ mcast_parse(const char *line)
 			PILCallLog(LOG, PIL_CRIT, "mcast [%s] missing ttl", dev);
 			return(HA_FAIL);
 		}
-		if (get_ttl(token, &ttl) == -1) {
+		if (get_ttl(token, &ttl) < 0 || ttl > 4) {
 			PILCallLog(LOG, PIL_CRIT, " mcast [%s] bad ttl [%d]", dev, ttl);
 			return HA_FAIL;
 		}
@@ -298,7 +274,7 @@ mcast_parse(const char *line)
 			PILCallLog(LOG, PIL_CRIT, "mcast [%s] missing loop", dev);
 			return(HA_FAIL);
 		}
-		if (get_loop(token, &loop) == -1) {
+		if (get_loop(token, &loop) < 0 ||	loop > 1) {
 			PILCallLog(LOG, PIL_CRIT, " mcast [%s] bad loop [%d]", dev, loop);
 			return HA_FAIL;
 		}
@@ -408,21 +384,20 @@ mcast_close(struct hb_media* hbm)
  * Receive a heartbeat multicast packet from UDP interface
  */
 
+char			mcast_pkt[MAXMSG];
 static void *
 mcast_read(struct hb_media* hbm, int *lenp)
 {
 	struct mcast_private *	mcp;
-	char			buf[MAXLINE];
 	socklen_t		addr_len = sizeof(struct sockaddr);
    	struct sockaddr_in	their_addr; /* connector's addr information */
 	int	numbytes;
-	void	*pkt;
 
 	MCASTASSERT(hbm);
 	mcp = (struct mcast_private *) hbm->pd;
 	
-	if ((numbytes=recvfrom(mcp->rsocket, buf, MAXLINE-1, 0
-			       ,(struct sockaddr *)&their_addr, &addr_len)) < 0) {
+	if ((numbytes=recvfrom(mcp->rsocket, mcast_pkt, MAXMSG-1, 0
+	,	(struct sockaddr *)&their_addr, &addr_len)) < 0) {
 		if (errno != EINTR) {
 			PILCallLog(LOG, PIL_CRIT, "Error receiving from socket: %s"
 			    ,	strerror(errno));
@@ -430,29 +405,19 @@ mcast_read(struct hb_media* hbm, int *lenp)
 		return NULL;
 	}
 	/* Avoid possible buffer overruns */
-	buf[numbytes] = EOS;
+	mcast_pkt[numbytes] = EOS;
 	
 	if (Debug >= PKTTRACE) {
 		PILCallLog(LOG, PIL_DEBUG, "got %d byte packet from %s"
 		    ,	numbytes, inet_ntoa(their_addr.sin_addr));
 	}
 	if (Debug >= PKTCONTTRACE && numbytes > 0) {
-		PILCallLog(LOG, PIL_DEBUG, "%s", buf);
+		PILCallLog(LOG, PIL_DEBUG, "%s", mcast_pkt);
 	}
 	
-	pkt = ha_malloc(numbytes + 1);
-	if(!pkt){
-		PILCallLog(LOG, PIL_CRIT
-		    ,	"Error in allocating memory");
-		return(NULL);
-	}
-	
-	memcpy(pkt, buf, numbytes + 1);
 	*lenp = numbytes + 1 ;
 
-	return(pkt);
-	
-	
+	return mcast_pkt;;
 }
 
 /*
@@ -529,7 +494,7 @@ mcast_make_send_sock(struct hb_media * hbm)
  * Set up socket for listening to heartbeats (UDP multicasts)
  */
 
-#define	MAXBINDTRIES	10
+#define	MAXBINDTRIES	50
 static int
 mcast_make_receive_sock(struct hb_media * hbm)
 {
@@ -730,32 +695,56 @@ join_mcast_group(int sockfd, struct in_addr *addr, char *ifname)
 static int
 if_getaddr(const char *ifname, struct in_addr *addr)
 {
-	int	fd;
 	struct ifreq	if_info;
+	int		j;
+	int		maxtry = 120;
+	gboolean	gotaddr = FALSE;
+	int		err = 0;
 	
-	if (!addr)
+	if (!addr) {
 		return -1;
+	}
 
 	addr->s_addr = INADDR_ANY;
 
 	memset(&if_info, 0, sizeof(if_info));
 	if (ifname) {
 		strncpy(if_info.ifr_name, ifname, IFNAMSIZ-1);
-	} else {	/* ifname is NULL, so use any address */
+	}else{	/* ifname is NULL, so use any address */
 		return 0;
 	}
 
-	if ((fd=socket(AF_INET, SOCK_DGRAM, 0)) == -1)	{
-		PILCallLog(LOG, PIL_CRIT, "Error getting socket");
-		return -1;
-	}
 	if (Debug > 0) {
-		PILCallLog(LOG, PIL_DEBUG,	"looking up address for %s"
+		PILCallLog(LOG, PIL_DEBUG, "looking up address for %s"
 		,	if_info.ifr_name);
 	}
-	if (ioctl(fd, SIOCGIFADDR, &if_info) == -1) {
-		PILCallLog(LOG, PIL_CRIT, "Error ioctl(SIOCGIFADDR)");
+	for (j=0; j < maxtry && !gotaddr; ++j) {
+		int		fd;
+		if ((fd=socket(AF_INET, SOCK_DGRAM, 0)) == -1)	{
+			PILCallLog(LOG, PIL_CRIT, "Error getting socket");
+			return -1;
+		}
+		if (ioctl(fd, SIOCGIFADDR, &if_info) >= 0) {
+			gotaddr = TRUE;
+		}else{
+			err = errno;
+			switch(err) {
+				case EADDRNOTAVAIL:
+					sleep(1);
+					break;	
+				default:
+					close(fd);
+					goto getout;
+			}
+		}
 		close(fd);
+	}
+getout:
+	if (!gotaddr) {
+		PILCallLog(LOG, PIL_CRIT
+		,	"Unable to retrieve local interface address"
+		" for interface [%s] using ioctl(SIOCGIFADDR): %s"
+		,	ifname, strerror(err));
 		return -1;
 	}
 
@@ -768,7 +757,6 @@ if_getaddr(const char *ifname, struct in_addr *addr)
 	memcpy(addr, &(SOCKADDR_IN(&if_info.ifr_addr)->sin_addr)
 	,	sizeof(struct in_addr));
 
-	close(fd);
 	return 0;
 }
 
@@ -829,123 +817,3 @@ get_loop(const char *loop, u_char *l)
 	return 0;
 }
 
-/*
- * $Log: mcast.c,v $
- * Revision 1.15.2.4  2005/01/12 02:25:47  horms
- * Fix gcc-4.0 compile problems (Andreas Jochens)
- *
- * Revision 1.15.2.3  2004/05/12 00:10:14  alan
- * Changed all the HBcomm plugins to use PILCallLog() for logging
- * instead of calling the function pointer directly.
- * Also, in the process fixed several mismatches between arguments
- * and format strings, and a couple of format string vulnerabilities.
- *
- * Revision 1.19  2004/05/11 22:04:35  alan
- * Changed all the HBcomm plugins to use PILCallLog() for logging instead of calling
- * the function pointer directly.
- * Also, in the process fixed several mismatches between arguments and format strings, and
- * a couple of format string vulnerabilities.
- *
- * Revision 1.18  2004/04/28 22:30:29  alan
- * Put in some fixes for extra freeing of memory in the communications plugins.
- *
- * Revision 1.17  2004/03/03 05:31:50  alan
- * Put in Gochun Shi's new netstrings on-the-wire data format code.
- * this allows sending binary data, among many other things!
- *
- * Revision 1.16  2004/02/17 22:11:59  lars
- * Pet peeve removal: _Id et al now gone, replaced with consistent Id header.
- *
- * Revision 1.15  2004/01/21 11:34:15  horms
- * - Replaced numerous malloc + strcpy/strncpy invocations with strdup
- *   * This usually makes the code a bit cleaner
- *   * Also is easier not to make code with potential buffer over-runs
- * - Added STRDUP to pils modules
- * - Removed some spurious MALLOC and FREE redefinitions
- *   _that could never be used_
- * - Make sure the return value of strdup is honoured in error conditions
- *
- * Revision 1.14  2003/02/07 08:37:17  horms
- * Removed inclusion of portability.h from .h files
- * so that it does not need to be installed.
- *
- * Revision 1.13  2003/02/05 09:06:34  horms
- * Lars put a lot of work into making sure that portability.h
- * is included first, everywhere. However this broke a few
- * things when building against heartbeat headers that
- * have been installed (usually somewhere under /usr/include or
- * /usr/local/include).
- *
- * This patch should resolve this problem without undoing all of
- * Lars's hard work.
- *
- * As an asside: I think that portability.h is a virus that has
- * infected all of heartbeat's code and now must also infect all
- * code that builds against heartbeat. I wish that it didn't need
- * to be included all over the place. Especially in headers to
- * be installed on the system. However, I respect Lars's opinion
- * that this is the best way to resolve some weird build problems
- * in the current tree.
- *
- * Revision 1.12  2003/01/31 10:02:09  lars
- * Various small code cleanups:
- * - Lots of "signed vs unsigned" comparison fixes
- * - time_t globally replaced with TIME_T
- * - All seqnos moved to "seqno_t", which defaults to unsigned long
- * - DIMOF() definition centralized to portability.h and typecast to int
- * - EOS define moved to portability.h
- * - dropped inclusion of signal.h from stonith.h, so that sigignore is
- *   properly defined
- *
- * Revision 1.11  2002/10/21 10:17:19  horms
- * hb api clients may now be built outside of the heartbeat tree
- *
- * Revision 1.10  2002/09/19 22:40:18  alan
- * Changed a few error return checks to not print anything and return
- * if an error was encountered.
- * Changed a few debug messages to only print if a strictly positive number
- * of chars was received.
- *
- * Revision 1.9  2002/09/12 03:52:07  alan
- * Fixed up a comment :-(.
- *
- * Revision 1.8  2002/09/12 03:39:45  alan
- * Fixed some logging level names in the code and also
- * fixed an error in the license chosen for a file.
- *
- * Revision 1.7  2002/06/16 06:11:26  alan
- * Put in a couple of changes to the PILS interfaces
- *  - exported license information (name, URL)
- *  - imported malloc/free
- *
- * Revision 1.6  2002/05/01 23:50:35  alan
- * Put in some comments about how the code avoids potential buffer overruns.
- *
- * Revision 1.5  2002/04/13 22:35:08  alan
- * Changed ha_msg_add_nv to take an end pointer to make it safer.
- * Added a length parameter to string2msg so it would be safer.
- * Changed the various networking plugins to use the new string2msg().
- *
- * Revision 1.4  2002/04/09 12:45:36  alan
- * Put in changes to the bcast, mcast and serial code such that
- * interrupted system calls in reads are ignored.
- *
- * Revision 1.3  2002/01/17 15:21:23  alan
- * Put in Ram Pai's patch for the bug in the multicast code.
- *
- * Revision 1.2  2001/09/07 16:18:17  alan
- * Updated ping.c to conform to the new plugin loading system.
- * Changed log messages in bcast, mcast, ping and serial to use the
- * new logging function.
- *
- * Revision 1.1  2001/08/10 17:16:44  alan
- * New code for the new plugin loading system.
- *
- * Revision 1.11  2001/06/23 04:30:26  alan
- * Changed the code to use inet_pton() when it's available, and
- * emulate it when it's not...  Patch was from Chris Wright.
- *
- * Revision 1.10  2001/06/08 04:57:48  alan
- * Changed "config.h" to <portability.h>
- *
- */
