@@ -21,11 +21,7 @@
  *
  */
 
-#include <portability.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include <lha_internal.h>
 
 #include "hbagent.h"
 
@@ -34,6 +30,22 @@
 #include "clplumbing/cl_log.h"
 #include "clplumbing/coredumps.h"
 
+#ifdef PACKAGE_BUGREPORT
+#undef PACKAGE_BUGREPORT
+#endif
+#ifdef PACKAGE_NAME
+#undef PACKAGE_NAME
+#endif
+#ifdef PACKAGE_STRING
+#undef PACKAGE_STRING
+#endif
+#ifdef PACKAGE_TARNAME
+#undef PACKAGE_TARNAME
+#endif
+#ifdef PACKAGE_VERSION
+#undef PACKAGE_VERSION
+#endif
+
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
@@ -148,7 +160,7 @@ static uint32_t IF_STATUS_VALUE[] =
 
 static RETSIGTYPE
 stop_server(int a) {
-    keep_running = 0;
+    	keep_running = 0;
 }
 
 uint32_t 
@@ -282,11 +294,11 @@ hbconfig_get_str_value(const char * attr, char * * value)
 
 	/* we have to return HA_OK here otherwise the 
 	   agent code would not progress */
-	*value  = ha_strdup(err);
+	*value  = cl_strdup(err);
 	return HA_OK;
     };
 
-    *value = ha_strdup(ret);
+    *value = cl_strdup(ret);
 
     return HA_OK;
 }
@@ -317,7 +329,7 @@ get_hb_info(lha_group_t group)
 static void
 NodeStatus(const char * node, const char * status, void * private)
 {
-        cl_log(LOG_NOTICE, "Status update: Node %s now has status %s\n"
+        cl_log(LOG_NOTICE, "Status update: Node %s now has status %s"
         ,       node, status);
 	walk_nodetable();
 
@@ -328,7 +340,7 @@ static void
 LinkStatus(const char * node, const char * lnk, const char * status
 ,       void * private)
 {
-        cl_log(LOG_NOTICE, "Link Status update: Link %s/%s now has status %s\n"
+        cl_log(LOG_NOTICE, "Link Status update: Link %s/%s now has status %s"
         ,       node, lnk, status);
 	walk_iftable();
 
@@ -364,7 +376,7 @@ free_nodetable(void)
 		node = (struct hb_nodeinfo *) g_ptr_array_remove_index_fast(gNodeTable, 0);
 
 		free(node->name);
-		ha_free(node);
+		cl_free(node);
 	}
 
 	return;
@@ -383,7 +395,7 @@ free_iftable(void)
 
 		free(interface->name);
 		free(interface->node);
-		ha_free(interface);
+		cl_free(interface);
 	}
 
 	return;
@@ -402,7 +414,7 @@ free_resourcetable(void)
 		resource = (struct hb_rsinfo *) g_ptr_array_remove_index_fast(gResourceTable, 0);
 
 		free(resource->resource);
-		ha_free(resource);
+		cl_free(resource);
 
 	}
 
@@ -462,8 +474,8 @@ init_heartbeat(void)
 	cl_log(LOG_DEBUG, "Signing in with heartbeat");
 
 	if (hb->llc_ops->signon(hb, LHAAGENTID)!= HA_OK) {
-		cl_log(LOG_ERR, "Cannot sign on with heartbeat\n");
-		cl_log(LOG_ERR, "REASON: %s\n", hb->llc_ops->errmsg(hb));
+		cl_log(LOG_ERR, "Cannot sign on with heartbeat");
+		cl_log(LOG_ERR, "REASON: %s", hb->llc_ops->errmsg(hb));
 		return HA_FAIL;
 	}
 
@@ -474,21 +486,21 @@ init_heartbeat(void)
 	}
 	cl_cdtocoredir();
 
-	if (NULL == (myid = ha_strdup(hb->llc_ops->get_mynodeid(hb)))) {
-		cl_log(LOG_ERR, "Cannot get mynodeid\n");
-		cl_log(LOG_ERR, "REASON: %s\n", hb->llc_ops->errmsg(hb));
+	if (NULL == (myid = cl_strdup(hb->llc_ops->get_mynodeid(hb)))) {
+		cl_log(LOG_ERR, "Cannot get mynodeid");
+		cl_log(LOG_ERR, "REASON: %s", hb->llc_ops->errmsg(hb));
 		return HA_FAIL;
 	}
 
 	if (hb->llc_ops->set_nstatus_callback(hb, NodeStatus, NULL) !=HA_OK){
-	        cl_log(LOG_ERR, "Cannot set node status callback\n");
-	        cl_log(LOG_ERR, "REASON: %s\n", hb->llc_ops->errmsg(hb));
+	        cl_log(LOG_ERR, "Cannot set node status callback");
+	        cl_log(LOG_ERR, "REASON: %s", hb->llc_ops->errmsg(hb));
 		return HA_FAIL;
 	}
 
 	if (hb->llc_ops->set_ifstatus_callback(hb, LinkStatus, NULL)!=HA_OK){
-	        cl_log(LOG_ERR, "Cannot set if status callback\n");
-	        cl_log(LOG_ERR, "REASON: %s\n", hb->llc_ops->errmsg(hb));
+	        cl_log(LOG_ERR, "Cannot set if status callback");
+	        cl_log(LOG_ERR, "REASON: %s", hb->llc_ops->errmsg(hb));
 		return HA_FAIL;
 	}
 
@@ -515,8 +527,8 @@ get_heartbeat_fd(void)
 	}
 
 	if ((fd = hb->llc_ops->inputfd(hb)) < 0) {
-		cl_log(LOG_ERR, "Cannot get inputfd\n");
-		cl_log(LOG_ERR, "REASON, %s\n", hb->llc_ops->errmsg(hb));
+		cl_log(LOG_ERR, "Cannot get inputfd");
+		cl_log(LOG_ERR, "REASON, %s", hb->llc_ops->errmsg(hb));
 	}
 	return fd;
 }
@@ -527,7 +539,7 @@ walk_nodetable(void)
 	const char *name, *type, *status;
 	struct hb_nodeinfo * node;
 	size_t id = 0;
-	uuid_t uuid;
+	cl_uuid_t uuid;
 
 	if (gNodeTable) {
 		free_nodetable();
@@ -544,11 +556,10 @@ walk_nodetable(void)
 		status = hb->llc_ops->node_status(hb, name);
 		type = hb->llc_ops->node_type(hb, name);
 
-		cl_log(LOG_INFO, "node %ld: %s, type: %s, status: %s"
-		,	(long)id, name 
+		cl_log(LOG_INFO, "node %ld: %s, type: %s, status: %s", (unsigned long)id, name 
 		,	type, status);
 
-		node = (struct hb_nodeinfo *) ha_malloc(sizeof(struct hb_nodeinfo));
+		node = (struct hb_nodeinfo *) cl_malloc(sizeof(struct hb_nodeinfo));
 		if (!node) {
 			cl_log(LOG_CRIT, "malloc failed for node info.");
 			return HA_FAIL;
@@ -558,15 +569,15 @@ walk_nodetable(void)
 		node->ifcount = 0;
 		node->id = id;
 
-		memset(uuid, 0, sizeof(uuid_t));
+		memset(&uuid, 0, sizeof(cl_uuid_t));
 
 #ifdef HAVE_NEW_HB_API
 		/* the get_uuid_by_name is not available for STABLE_1_2 branch. */
-		if (hb->llc_ops->get_uuid_by_name(hb, name, uuid) == HA_FAIL) {
+		if (hb->llc_ops->get_uuid_by_name(hb, name, &uuid) == HA_FAIL) {
 			cl_log(LOG_DEBUG, "Cannot get the uuid for node: %s", name);
 		}
 #endif /* HAVE_NEW_HB_API */
-		memcpy(node->uuid, uuid, sizeof(uuid_t));
+		node->uuid = uuid;
 
 		node->type = get_status_value(type, NODE_TYPE, NODE_TYPE_VALUE);
 		node->status = get_status_value(status, NODE_STATUS,
@@ -611,7 +622,7 @@ walk_iftable(void)
 			cl_log(LOG_INFO, "node: %s, interface: %s, status: %s",
 					node->name, name, status);
 
-			interface = (struct hb_ifinfo *) ha_malloc(sizeof(struct hb_ifinfo));
+			interface = (struct hb_ifinfo *) cl_malloc(sizeof(struct hb_ifinfo));
 			if (!interface) {
 				cl_log(LOG_CRIT, "malloc failed for if info.");
 				return HA_FAIL;
@@ -641,25 +652,36 @@ walk_iftable(void)
 int
 handle_heartbeat_msg(void)
 {
-	struct ha_msg *msg;
-	const char *type, *node;
+	IPC_Channel * chan;
+	struct ha_msg * msg;
+	const char * type, * node;
 
 	while (hb->llc_ops->msgready(hb)) {
 
+		chan = hb->llc_ops->ipcchan(hb);
+		/* this happens when the main heartbeat daemon is not there
+		   any more */
+		if (chan->ch_status == IPC_DISCONNECT) {
+			return HA_FAIL;
+		} 
+
 		msg = hb->llc_ops->readmsg(hb, 0);
-		if (!msg)
-		    	break;
+		if (!msg) {
+			cl_log(LOG_DEBUG, "read_hb_msg returned NULL.");
+			continue;
+		}
 
 		type = ha_msg_value(msg, F_TYPE);
 		node = ha_msg_value(msg, F_ORIG);
 		if (!type || !node) {
 			/* can't read type. log and ignore the msg. */
-			cl_log(LOG_DEBUG, "Can't read msg type.\n");
+			cl_log(LOG_DEBUG, "Can't read msg type.");
 			return HA_OK;
 		}
 
 		/* we only handle the shutdown msg for now. */
-		if (strcmp(myid, node) == 0 && strncmp(type, T_SHUTDONE, 20) == 0) {
+		if (strcmp(myid, node) == 0
+		&&		STRNCMP_CONST(type, T_SHUTDONE) == 0) {
 			return HA_FAIL;
 		}
 		ha_msg_del(msg);
@@ -689,7 +711,7 @@ clm_track_cb(SaClmClusterNotificationT *nbuf, SaUint32T nitem,
 
 		for (i = 0; i < nitem; i++) {
 		    	status = nbuf[i].clusterChanges;
-			node = nbuf[i].clusterNode.nodeName.value;
+			node = (char *)nbuf[i].clusterNode.nodeName.value;
 
 			if (status == SA_CLM_NODE_NO_CHANGE) {
 			    	continue;
@@ -726,24 +748,29 @@ init_membership(void)
 	    return HA_OK;
 	}
 
-	if (nbuf)
-		ha_free(nbuf);
+	if (nbuf) {
+		cl_free(nbuf);
+	}
 
-        nbuf = (SaClmClusterNotificationT *) ha_malloc(gNodeTable->len *
+        nbuf = (SaClmClusterNotificationT *) cl_malloc(gNodeTable->len *
                                 sizeof (SaClmClusterNotificationT));
+	if (!nbuf) {
+		cl_log(LOG_ERR, "%s: cl_malloc failed for SaClmClusterNotificationT.", __FUNCTION__);
+		return HA_FAIL;
+	}
 
         if (saClmClusterTrackStart(&handle, SA_TRACK_CURRENT, nbuf,
                 gNodeTable->len) != SA_OK) {
-                cl_log(LOG_ERR, "SA_TRACK_CURRENT error, errno [%d]\n", ret);
-                ha_free(nbuf);
+                cl_log(LOG_ERR, "SA_TRACK_CURRENT error, errno [%d]", ret);
+                cl_free(nbuf);
                 return HA_FAIL;
         }
 
         /* Start to track cluster membership changes events */
         if (saClmClusterTrackStart(&handle, SA_TRACK_CHANGES, nbuf,
                 gNodeTable->len) != SA_OK) {
-                cl_log(LOG_ERR, "SA_TRACK_CURRENT error, errno [%d]\n", ret);
-                ha_free(nbuf);
+                cl_log(LOG_ERR, "SA_TRACK_CURRENT error, errno [%d]", ret);
+                cl_free(nbuf);
                 return HA_FAIL;
         }
 
@@ -765,7 +792,7 @@ get_membership_fd(void)
 		return 0;
 
 	if ((ret = saClmSelectionObjectGet(&clm, &st)) != SA_OK) {
-	    	cl_log(LOG_ERR, "saClmSelectionObjectGet error, errno [%d]\n", ret);
+	    	cl_log(LOG_ERR, "saClmSelectionObjectGet error, errno [%d]", ret);
 		return -1;
 	} 
 
@@ -786,7 +813,9 @@ handle_membership_msg(void)
 			   again later. */
 			clmInitialized = 0;
 			free_membershiptable();
-
+                        
+                        /* finalize membership */
+                        saClmFinalize(&clm);
 			return HA_OK;
 		} else {
 		    cl_log(LOG_WARNING, "saClmDispatch error, ret = [%d]", ret);
@@ -866,9 +895,10 @@ init_resource_table(void)
 		if (!found)
 		    continue;
 
-		resource = (struct hb_rsinfo *) ha_malloc(sizeof(struct hb_rsinfo));
+		resource = (struct hb_rsinfo *) cl_malloc(sizeof(struct hb_rsinfo));
 		if (!resource) {
 			cl_log(LOG_CRIT, "malloc resource info failed.");
+			fclose(rcsf);
 			return HA_FAIL;
 		}
 
@@ -879,6 +909,7 @@ init_resource_table(void)
 		g_ptr_array_add(gResourceTable, (gpointer *) resource);
 	}
 
+	fclose(rcsf);
 	return HA_OK;
 }
 
@@ -897,7 +928,7 @@ rsinfo_get_int_value(lha_attribute_t attr, size_t index, uint32_t * value)
     switch (attr) {
 	case RESOURCE_STATUS:
 	    resource = ((struct hb_rsinfo *) g_ptr_array_index(gResourceTable, index))->resource;
-	    sprintf(getcmd, HALIB "/ResourceManager status %s", resource);
+	    sprintf(getcmd, HA_NOARCHDATAHBDIR "/ResourceManager status %s", resource);
 	    rc = system(getcmd);
 	    /* cl_log(LOG_INFO, "resource [%s] status: [%d]", resource, WEXITSTATUS(rc)); */
 
@@ -1048,6 +1079,8 @@ ifstatus_trap(const char * node, const char * lnk, const char * status)
 int 
 hbagent_trap(int online, const char * node)
 {
+    netsnmp_variable_list *notification_vars = NULL;
+
     oid objid_snmptrap[] = { 1, 3, 6, 1, 6, 3, 1, 1, 4, 1, 0 };
     size_t objid_snmptrap_len = OID_LENGTH(objid_snmptrap);
 
@@ -1063,7 +1096,6 @@ hbagent_trap(int online, const char * node)
 	    trap_oid[trap_oid_len - 1] = 9;
     }
 
-    netsnmp_variable_list *notification_vars = NULL;
 
     snmp_varlist_add_variable(&notification_vars,
                               /*
@@ -1169,6 +1201,7 @@ main(int argc, char ** argv)
 	fd_set fdset;
 	struct timeval tv, *tvp;
 	int flag, block = 0, numfds, hb_fd = 0, mem_fd = 0, debug = 0;
+	int hb_already_dead = 0;
 
 	/* change this if you want to be a SNMP master agent */
 	int agentx_subagent=1; 
@@ -1305,8 +1338,22 @@ main(int argc, char ** argv)
 		ret = select(numfds, &fdset, 0, 0, tvp);
 
 		if (ret < 0) {
+			if (errno == EBADF) {
+				struct stat	foo;
+				/* Probably the membership layer shut down for some reason. */
+				if (mem_fd >= 0 && fstat(mem_fd, &foo) < 0 && errno == EBADF) {
+					cl_log(LOG_WARNING, "membership layer shut down.");
+					FD_CLR(mem_fd, &fdset);
+					if (numfds == mem_fd + 1) {
+						numfds--;
+					}
+					mem_fd = -1;
+					break;
+				}
+			}
+				
 			/* error */
-			cl_log(LOG_ERR, "select() returned with an error. shutting down...");
+			cl_perror("select() returned an error. shutting down");
 			break;
 		} else if (ret == 0) {
 			/* timeout */
@@ -1320,6 +1367,7 @@ main(int argc, char ** argv)
 
 			if ((ret = handle_heartbeat_msg()) == HA_FAIL) {
 				cl_log(LOG_DEBUG, "no heartbeat. quit now.");
+				hb_already_dead = 1;
 				break;
 			}
 		} else  if (clmInitialized && FD_ISSET(mem_fd, &fdset)) {
@@ -1345,9 +1393,21 @@ process_pending:
 	
 	hbagent_trap(0, myid);
 	snmp_shutdown("LHA-agent");
-	ha_free(myid);
+
+	cl_free(myid);
 	free_storage();
 
+        if (!hb_already_dead && hb->llc_ops->signoff(hb, TRUE) != HA_OK) {
+                cl_log(LOG_ERR, "Cannot sign off from heartbeat.");
+                cl_log(LOG_ERR, "REASON: %s", hb->llc_ops->errmsg(hb));
+                exit(10);
+        }
+        if (hb->llc_ops->delete(hb) != HA_OK) {
+                cl_log(LOG_ERR, "Cannot delete API object.");
+                cl_log(LOG_ERR, "REASON: %s", hb->llc_ops->errmsg(hb));
+                exit(11);
+        }
+
 	return 0;
 }
 
